@@ -1,4 +1,4 @@
-NUM_VERSION = (2013, 1)
+NUM_VERSION = (2013, 2)
 VERSION = ".".join(str(nv) for nv in NUM_VERSION)
 __version__ = VERSION
 
@@ -144,12 +144,21 @@ def set_interrupt_handler(interrupt_signal=DEFAULT_SIGNAL):
     Note, this may not work if you use threads or subprocesses.
     """
     import signal
-    signal.signal(interrupt_signal, _interrupt_handler)
+    try:
+        signal.signal(interrupt_signal, _interrupt_handler)
+    except ValueError:
+        from pudb.lowlevel import format_exception
+        import sys
+        from warnings import warn
+        warn("setting interrupt handler on signal %d failed: %s"
+                % (interrupt_signal, "".join(format_exception(sys.exc_info()))))
 
-def post_mortem(exc_info=None):
-    if exc_info is None:
+def post_mortem(tb=None, e_type=None, e_value=None):
+    if tb is None:
         import sys
         exc_info = sys.exc_info()
+    else:
+        exc_info = (e_type, e_value, tb)
 
     tb = exc_info[2]
     while tb.tb_next is not None:
@@ -171,7 +180,7 @@ def pm():
     except AttributeError:
         ## No exception on record. Do nothing.
         return
-    post_mortem((e_type, e_value, tb))
+    post_mortem(tb, e_type, e_value)
 
 
 
