@@ -151,6 +151,24 @@ class Debugger(bdb.Bdb):
         for bpoint_descr in load_breakpoints():
             self.set_break(*bpoint_descr)
 
+    def set_trace(self, frame=None):
+        """Start debugging from `frame`.
+
+        If frame is not specified, debugging starts from caller's frame.
+        
+        This is exactly the same as Bdb.set_trace(), sans the self.reset() call.
+        """
+        if frame is None:
+            frame = sys._getframe().f_back
+        # See pudb issue #52. If this works well enough we should upstream to stdlib bdb.py.
+        #self.reset()
+        while frame:
+            frame.f_trace = self.trace_dispatch
+            self.botframe = frame
+            frame = frame.f_back
+        self.set_step()
+        sys.settrace(self.trace_dispatch)
+
     def save_breakpoints(self):
         from pudb.settings import save_breakpoints
         save_breakpoints([
@@ -330,7 +348,10 @@ from pudb.ui_tools import make_hotkey_markup, labelled_value, \
         SelectableText, SignalWrap, StackFrame, BreakpointFrame
 
 from pudb.var_view import FrameVarInfoKeeper
-
+try:
+    import curses
+except ImportError:
+    curses = None
 
 from urwid.raw_display import Screen
 
@@ -757,7 +778,7 @@ class DebuggerUI(FrameVarInfoKeeper):
             self.source.set_focus(0)
 
         def move_end(w, size, key):
-            self.source.set_focus(len(self.source))
+            self.source.set_focus(len(self.source)-1)
 
         def go_to_line(w, size, key):
             _, line = self.source.get_focus()
@@ -1149,6 +1170,14 @@ class DebuggerUI(FrameVarInfoKeeper):
         # {{{ setup
 
         self.screen = ThreadsafeScreen()
+
+        if curses:
+            curses.setupterm()
+            color_support = curses.tigetnum('colors')
+
+            if color_support == 256:
+                self.screen.set_terminal_properties(256)
+
         self.setup_palette(self.screen)
 
         self.show_count = 0
@@ -1353,7 +1382,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                 self.message("Package 'pygments' not found. "
                         "Syntax highlighting disabled.")
 
-        WELCOME_LEVEL = "e008"
+        WELCOME_LEVEL = "e009"
         if CONFIG["seen_welcome"] < WELCOME_LEVEL:
             CONFIG["seen_welcome"] = WELCOME_LEVEL
             from pudb import VERSION
@@ -1367,6 +1396,8 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "look familiar.\n\n"
                     "If you're new here, welcome! The help screen (invoked by hitting "
                     "'?' after this message) should get you on your way.\n"
+                    "\nChanges in version 2013.2:\n\n"
+                    "- Even more bug fixes.\n"
                     "\nChanges in version 2013.1:\n\n"
                     "- Ctrl-C will now break to the debugger in a way that does\n"
                     "  not terminate the program\n"
